# 1 "xml_lexer.mll"
 (*
 * Xml Light, an small Xml parser/printer with DTD support.
 * Copyright (C) 2003 Nicolas Cannasse (ncannasse@motion-twin.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library has the special exception on linking described in file
 * README.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 *)

open Lexing
open Xml_parser
open Dtd

type error =
	| EUnterminatedComment
	| EUnterminatedString
	| EIdentExpected
	| ECloseExpected
	| ENodeExpected
	| EAttributeNameExpected
	| EAttributeValueExpected
	| EUnterminatedEntity

type dtd_error =
	| EInvalidDTDDecl
	| EInvalidDTDTag
	| EDTDItemExpected
	| EInvalidDTDElement
	| EInvalidDTDAttribute

exception Error of error
exception DTDError of dtd_error

type pos = int * int * int * int

type dtd_decl =
	| DTDFile of string
	| DTDData of dtd

type dtd_item_type =
	| TElement
	| TAttribute

type token =
	| Tag of string * (string * string) list * bool
	| PCData of string
	| Endtag of string
	| DocType of (string * dtd_decl)
	| Eof

let last_pos = ref 0
and current_line = ref 0
and current_line_start = ref 0

let tmp = Buffer.create 200


let entities = [
  "gt"  ,62, ">";
  "lt"  ,60, "<";
  "amp" ,38, "&";
  "apos",39, "'";
  "quot",34, "\"";
]

let idents = Hashtbl.create 0
let _ = begin
  List.iter (fun (str,code,res) ->
      Hashtbl.add idents (str^";") res;
      if code > 0
      then Hashtbl.add idents ("#" ^ string_of_int code ^ ";") res
    ) entities
end

let init lexbuf =
	current_line := 1;
	current_line_start := lexeme_start lexbuf;
	last_pos := !current_line_start

let close lexbuf =
	Buffer.reset tmp

let pos lexbuf =
	!current_line ,	!current_line_start ,
	!last_pos ,
	lexeme_start lexbuf

let restore (cl,cls,lp,_) =
	current_line := cl;
	current_line_start := cls;
	last_pos := lp

let newline lexbuf =
	incr current_line;
	last_pos := lexeme_end lexbuf;
	current_line_start := !last_pos

let error lexbuf e =
	last_pos := lexeme_start lexbuf;
	raise (Error e)

let dtd_error lexbuf e =
	last_pos := lexeme_start lexbuf;
	raise (DTDError e)

# 122 "xml_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base =
   "\000\000\244\255\245\255\001\000\247\255\003\000\008\000\009\000\
    \255\255\011\000\017\000\250\255\000\000\001\000\000\000\000\000\
    \003\000\000\000\000\000\000\000\003\000\253\255\005\000\000\000\
    \001\000\009\000\001\000\252\255\251\255\020\000\044\000\255\255\
    \006\000\252\255\253\255\003\000\255\255\013\000\254\255\014\000\
    \252\255\253\255\016\000\255\255\254\255\005\000\251\255\000\000\
    \254\255\015\000\019\000\253\255\073\000\254\255\077\000\075\000\
    \253\255\152\000\237\000\255\255\056\001\162\000\176\000\131\001\
    \254\255\169\001\254\255\247\001\020\000\254\255\255\255\041\000\
    \032\000\255\255\254\255\069\002\254\255\147\002\190\000\253\255\
    \005\003\006\003\008\003\009\003\254\255\255\255\003\000\252\255\
    \253\255\008\000\255\255\254\255\074\000\252\255\253\255\015\000\
    \255\255\254\255\021\000\252\255\253\255\007\000\017\000\043\000\
    \038\000\043\000\051\000\255\255\036\000\036\000\052\000\045\000\
    \254\255\200\000\253\255\254\255\255\255\041\000\255\255\011\003\
    \251\000\254\255\255\255\074\000\254\255\255\255\078\000\253\255\
    \001\000\010\000\011\000\255\255\105\000\255\255\171\000\253\255\
    \084\000\093\000\101\000\094\000\129\000\142\000\139\000\255\255\
    \151\000\161\000\165\000\164\000\164\000\254\255\215\000\252\255\
    \253\255\172\000\172\000\163\000\255\255\173\000\170\000\169\000\
    \254\255\201\000\254\255\255\255\204\000\254\255\255\255\036\003\
    \243\255\114\003\245\255\246\255\247\255\187\000\249\255\250\255\
    \251\255\252\255\253\255\180\001\255\255\201\000\201\000\214\000\
    \197\000\217\000\248\255\239\002\250\255\251\255\227\000\220\000\
    \230\000\234\000\216\000\236\000\255\255\244\000\252\000\001\001\
    \045\001\038\001\254\255\035\001\049\001\049\001\252\255\203\003\
    \254\255\025\004\079\001\253\255\254\255\255\255\113\001\249\255\
    \134\001\254\255\255\255\080\001\077\001\074\001\122\001\111\001\
    \109\001\122\001\123\001\137\001\140\001\253\255\129\001\134\001\
    \138\001\144\001\147\001\252\255\172\001\192\001\194\001\251\255\
    \193\001\200\001\208\001\218\001\222\001\250\255\048\002\253\255\
    \254\255\255\255";
  Lexing.lex_backtrk =
   "\255\255\255\255\255\255\009\000\255\255\007\000\001\000\001\000\
    \255\255\006\000\007\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\002\000\001\000\255\255\
    \255\255\255\255\255\255\003\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\003\000\255\255\255\255\255\255\255\255\003\000\
    \255\255\000\000\255\255\255\255\002\000\255\255\000\000\255\255\
    \255\255\002\000\002\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\002\000\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \002\000\002\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\003\000\255\255\255\255\255\255\255\255\255\255\003\000\
    \255\255\255\255\255\255\255\255\255\255\003\000\003\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\001\000\255\255\003\000\
    \002\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \002\000\001\000\255\255\255\255\001\000\255\255\255\255\255\255\
    \002\000\002\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\003\000\003\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\011\000\255\255\255\255\255\255\012\000\255\255\255\255\
    \255\255\255\255\255\255\001\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\005\000\005\000\
    \005\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\002\000\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \006\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255";
  Lexing.lex_default =
   "\003\000\000\000\000\000\003\000\000\000\255\255\255\255\003\000\
    \000\000\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\000\000\000\000\255\255\255\255\000\000\
    \033\000\000\000\000\000\255\255\000\000\255\255\000\000\040\000\
    \000\000\000\000\255\255\000\000\000\000\049\000\000\000\255\255\
    \000\000\049\000\255\255\000\000\054\000\000\000\054\000\056\000\
    \000\000\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \000\000\066\000\000\000\255\255\069\000\000\000\000\000\255\255\
    \255\255\000\000\000\000\076\000\000\000\255\255\079\000\000\000\
    \255\255\255\255\255\255\255\255\000\000\000\000\087\000\000\000\
    \000\000\255\255\000\000\000\000\093\000\000\000\000\000\255\255\
    \000\000\000\000\099\000\000\000\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \000\000\114\000\000\000\000\000\000\000\255\255\000\000\255\255\
    \255\255\000\000\000\000\124\000\000\000\000\000\127\000\000\000\
    \255\255\255\255\255\255\000\000\255\255\000\000\135\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\000\000\151\000\000\000\
    \000\000\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \000\000\162\000\000\000\000\000\165\000\000\000\000\000\168\000\
    \000\000\255\255\000\000\000\000\000\000\255\255\000\000\000\000\
    \000\000\000\000\000\000\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\000\000\188\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\000\000\208\000\
    \000\000\255\255\211\000\000\000\000\000\000\000\215\000\000\000\
    \255\255\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\000\000\247\000\000\000\
    \000\000\000\000";
  Lexing.lex_trans =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\007\000\008\000\255\255\010\000\006\000\255\255\048\000\
    \036\000\006\000\007\000\255\255\009\000\006\000\006\000\000\000\
    \043\000\255\255\010\000\000\000\000\000\030\000\031\000\000\000\
    \007\000\030\000\129\000\010\000\012\000\090\000\004\000\255\255\
    \006\000\007\000\091\000\009\000\000\000\013\000\028\000\255\255\
    \037\000\010\000\009\000\035\000\030\000\030\000\097\000\130\000\
    \131\000\030\000\000\000\000\000\005\000\255\255\001\000\255\255\
    \009\000\024\000\011\000\022\000\015\000\255\255\017\000\255\255\
    \021\000\023\000\026\000\038\000\030\000\042\000\044\000\016\000\
    \020\000\051\000\070\000\255\255\018\000\025\000\255\255\255\255\
    \072\000\019\000\255\255\014\000\027\000\050\000\074\000\089\000\
    \108\000\024\000\047\000\022\000\091\000\102\000\103\000\073\000\
    \101\000\023\000\026\000\097\000\255\255\104\000\057\000\053\000\
    \100\000\096\000\105\000\255\255\106\000\025\000\107\000\109\000\
    \110\000\111\000\112\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\255\255\118\000\255\255\
    \125\000\255\255\128\000\255\255\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\095\000\133\000\
    \144\000\138\000\139\000\140\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\141\000\081\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\142\000\064\000\081\000\143\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\116\000\145\000\136\000\146\000\147\000\115\000\
    \137\000\063\000\063\000\063\000\063\000\063\000\063\000\148\000\
    \149\000\157\000\155\000\080\000\156\000\158\000\159\000\152\000\
    \002\000\255\255\160\000\088\000\120\000\046\000\034\000\163\000\
    \120\000\255\255\166\000\181\000\182\000\183\000\041\000\255\255\
    \062\000\063\000\063\000\063\000\063\000\063\000\063\000\184\000\
    \154\000\185\000\186\000\120\000\153\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\203\000\
    \059\000\197\000\193\000\194\000\195\000\196\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \198\000\255\255\094\000\199\000\200\000\255\255\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\201\000\059\000\202\000\204\000\205\000\206\000\
    \213\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\218\000\216\000\240\000\236\000\230\000\
    \217\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\179\000\064\000\223\000\
    \224\000\179\000\225\000\226\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\219\000\212\000\220\000\227\000\228\000\221\000\
    \229\000\231\000\232\000\233\000\179\000\234\000\067\000\235\000\
    \222\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\237\000\238\000\239\000\241\000\
    \067\000\242\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\243\000\244\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\245\000\000\000\000\000\000\000\000\000\000\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\249\000\000\000\000\000\000\000\067\000\248\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\077\000\000\000\000\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \000\000\000\000\000\000\000\000\077\000\000\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\000\000\000\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\000\000\000\000\
    \000\000\000\000\077\000\000\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\082\000\083\000\
    \000\000\082\000\083\000\000\000\120\000\121\000\000\000\189\000\
    \120\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\082\000\083\000\085\000\
    \082\000\083\000\085\000\120\000\084\000\179\000\180\000\084\000\
    \000\000\179\000\192\000\000\000\000\000\000\000\000\000\000\000\
    \190\000\000\000\000\000\000\000\000\000\191\000\000\000\000\000\
    \000\000\000\000\000\000\082\000\179\000\000\000\082\000\173\000\
    \000\000\000\000\000\000\000\000\178\000\177\000\172\000\171\000\
    \176\000\169\000\000\000\000\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\000\000\
    \000\000\000\000\175\000\170\000\000\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\000\000\
    \000\000\000\000\000\000\169\000\000\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \174\000\000\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\000\000\000\000\000\000\
    \000\000\169\000\000\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \209\000\000\000\000\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\000\000\000\000\
    \000\000\000\000\000\000\122\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\000\000\000\000\
    \000\000\000\000\209\000\000\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\000\000\
    \000\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\000\000\000\000\000\000\000\000\
    \209\000\000\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000";
  Lexing.lex_check =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\003\000\005\000\000\000\003\000\045\000\
    \032\000\006\000\007\000\007\000\009\000\006\000\007\000\255\255\
    \039\000\049\000\010\000\255\255\255\255\029\000\029\000\255\255\
    \000\000\029\000\128\000\005\000\005\000\086\000\000\000\003\000\
    \006\000\007\000\089\000\009\000\255\255\012\000\013\000\007\000\
    \035\000\010\000\005\000\032\000\029\000\030\000\095\000\129\000\
    \130\000\030\000\255\255\255\255\000\000\003\000\000\000\003\000\
    \010\000\023\000\005\000\014\000\012\000\007\000\016\000\007\000\
    \020\000\022\000\025\000\037\000\030\000\039\000\042\000\015\000\
    \019\000\050\000\068\000\052\000\017\000\024\000\052\000\054\000\
    \071\000\018\000\054\000\012\000\026\000\047\000\072\000\086\000\
    \101\000\023\000\045\000\014\000\089\000\098\000\102\000\071\000\
    \098\000\022\000\025\000\095\000\049\000\103\000\055\000\052\000\
    \098\000\092\000\104\000\054\000\105\000\024\000\106\000\108\000\
    \109\000\110\000\111\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\052\000\117\000\052\000\
    \123\000\054\000\126\000\054\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\092\000\132\000\
    \136\000\137\000\138\000\139\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\140\000\078\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\141\000\061\000\078\000\142\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\113\000\144\000\134\000\145\000\146\000\113\000\
    \134\000\062\000\062\000\062\000\062\000\062\000\062\000\147\000\
    \148\000\153\000\154\000\078\000\155\000\157\000\158\000\150\000\
    \000\000\003\000\159\000\086\000\120\000\045\000\032\000\161\000\
    \120\000\007\000\164\000\173\000\181\000\182\000\039\000\049\000\
    \057\000\062\000\062\000\062\000\062\000\062\000\062\000\183\000\
    \150\000\184\000\185\000\120\000\150\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\190\000\
    \058\000\191\000\192\000\193\000\194\000\195\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \197\000\052\000\092\000\198\000\199\000\054\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\200\000\060\000\201\000\203\000\204\000\205\000\
    \210\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\214\000\214\000\219\000\220\000\221\000\
    \214\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\179\000\063\000\222\000\
    \223\000\179\000\224\000\225\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\216\000\210\000\216\000\226\000\227\000\216\000\
    \228\000\230\000\231\000\232\000\179\000\233\000\065\000\234\000\
    \216\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\236\000\237\000\238\000\240\000\
    \065\000\241\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\067\000\242\000\243\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\244\000\255\255\255\255\255\255\255\255\255\255\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\246\000\255\255\255\255\255\255\067\000\246\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\075\000\255\255\255\255\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \255\255\255\255\255\255\255\255\075\000\255\255\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \077\000\255\255\255\255\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\255\255\255\255\
    \255\255\255\255\077\000\255\255\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\080\000\081\000\
    \255\255\082\000\083\000\255\255\119\000\119\000\255\255\187\000\
    \119\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\080\000\081\000\080\000\
    \082\000\083\000\082\000\119\000\080\000\167\000\167\000\082\000\
    \255\255\167\000\187\000\255\255\255\255\255\255\255\255\255\255\
    \187\000\255\255\255\255\255\255\255\255\187\000\255\255\255\255\
    \255\255\255\255\255\255\081\000\167\000\255\255\083\000\167\000\
    \255\255\255\255\255\255\255\255\167\000\167\000\167\000\167\000\
    \167\000\167\000\255\255\255\255\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\255\255\
    \255\255\255\255\167\000\167\000\255\255\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\255\255\
    \255\255\255\255\255\255\167\000\255\255\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\169\000\
    \167\000\255\255\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\255\255\255\255\255\255\
    \255\255\169\000\255\255\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \207\000\255\255\255\255\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\255\255\255\255\
    \255\255\255\255\255\255\119\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\255\255\255\255\
    \255\255\255\255\207\000\255\255\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\209\000\255\255\
    \255\255\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\255\255\255\255\255\255\255\255\
    \209\000\255\255\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255";
  Lexing.lex_base_code =
   "";
  Lexing.lex_backtrk_code =
   "";
  Lexing.lex_default_code =
   "";
  Lexing.lex_trans_code =
   "";
  Lexing.lex_check_code =
   "";
  Lexing.lex_code =
   "";
}

let rec token lexbuf =
   __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 132 "xml_lexer.mll"
  (
			newline lexbuf;
			token lexbuf
		)
# 577 "xml_lexer.ml"

  | 1 ->
# 137 "xml_lexer.mll"
  (
			last_pos := lexeme_end lexbuf;
			token lexbuf
		)
# 585 "xml_lexer.ml"

  | 2 ->
# 142 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			ignore_spaces lexbuf;
			let root = ident_name lexbuf in
			ignore_spaces lexbuf;
			let data = dtd_data lexbuf in
			DocType (root, data)
		)
# 597 "xml_lexer.ml"

  | 3 ->
# 151 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			Buffer.reset tmp;
			PCData (cdata lexbuf)
		)
# 606 "xml_lexer.ml"

  | 4 ->
# 157 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			comment lexbuf;
			token lexbuf
		)
# 615 "xml_lexer.ml"

  | 5 ->
# 163 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			header lexbuf;
			token lexbuf;
		)
# 624 "xml_lexer.ml"

  | 6 ->
# 169 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			let tag = ident_name lexbuf in
			ignore_spaces lexbuf;
			close_tag lexbuf;
			Endtag tag
		)
# 635 "xml_lexer.ml"

  | 7 ->
# 177 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			let tag = ident_name lexbuf in
			ignore_spaces lexbuf;
			let attribs, closed = attributes lexbuf in
			Tag(tag, attribs, closed)
		)
# 646 "xml_lexer.ml"

  | 8 ->
# 185 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			Buffer.reset tmp;
			Buffer.add_string tmp (entity lexbuf);
			PCData (pcdata lexbuf)
		)
# 656 "xml_lexer.ml"

  | 9 ->
# 192 "xml_lexer.mll"
  (
			last_pos := lexeme_start lexbuf;
			Buffer.reset tmp;
			Buffer.add_string tmp (lexeme lexbuf);
			PCData (pcdata lexbuf)
		)
# 666 "xml_lexer.ml"

  | 10 ->
# 198 "xml_lexer.mll"
       ( Eof )
# 671 "xml_lexer.ml"

  | 11 ->
# 200 "xml_lexer.mll"
  ( error lexbuf ENodeExpected )
# 676 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and ignore_spaces lexbuf =
   __ocaml_lex_ignore_spaces_rec lexbuf 29
and __ocaml_lex_ignore_spaces_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 204 "xml_lexer.mll"
  (
			newline lexbuf;
			ignore_spaces lexbuf
		)
# 691 "xml_lexer.ml"

  | 1 ->
# 209 "xml_lexer.mll"
  ( ignore_spaces lexbuf )
# 696 "xml_lexer.ml"

  | 2 ->
# 211 "xml_lexer.mll"
  ( () )
# 701 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_ignore_spaces_rec lexbuf __ocaml_lex_state

and comment lexbuf =
   __ocaml_lex_comment_rec lexbuf 32
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 215 "xml_lexer.mll"
  (
			newline lexbuf;
			comment lexbuf
		)
# 716 "xml_lexer.ml"

  | 1 ->
# 220 "xml_lexer.mll"
  ( () )
# 721 "xml_lexer.ml"

  | 2 ->
# 222 "xml_lexer.mll"
  ( raise (Error EUnterminatedComment) )
# 726 "xml_lexer.ml"

  | 3 ->
# 224 "xml_lexer.mll"
  ( comment lexbuf )
# 731 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

and header lexbuf =
   __ocaml_lex_header_rec lexbuf 39
and __ocaml_lex_header_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 228 "xml_lexer.mll"
  (
			newline lexbuf;
			header lexbuf
		)
# 746 "xml_lexer.ml"

  | 1 ->
# 233 "xml_lexer.mll"
  ( () )
# 751 "xml_lexer.ml"

  | 2 ->
# 235 "xml_lexer.mll"
  ( error lexbuf ECloseExpected )
# 756 "xml_lexer.ml"

  | 3 ->
# 237 "xml_lexer.mll"
  ( header lexbuf )
# 761 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_header_rec lexbuf __ocaml_lex_state

and cdata lexbuf =
   __ocaml_lex_cdata_rec lexbuf 45
and __ocaml_lex_cdata_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 241 "xml_lexer.mll"
  (
			Buffer.add_string tmp (lexeme lexbuf);
			cdata lexbuf
		)
# 776 "xml_lexer.ml"

  | 1 ->
# 246 "xml_lexer.mll"
  (
			newline lexbuf;
			Buffer.add_string tmp (lexeme lexbuf);
			cdata lexbuf
		)
# 785 "xml_lexer.ml"

  | 2 ->
# 252 "xml_lexer.mll"
  ( Buffer.contents tmp )
# 790 "xml_lexer.ml"

  | 3 ->
# 254 "xml_lexer.mll"
  (
			Buffer.add_string tmp (lexeme lexbuf);
			cdata lexbuf
		)
# 798 "xml_lexer.ml"

  | 4 ->
# 259 "xml_lexer.mll"
  ( error lexbuf ECloseExpected )
# 803 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_cdata_rec lexbuf __ocaml_lex_state

and pcdata lexbuf =
   __ocaml_lex_pcdata_rec lexbuf 52
and __ocaml_lex_pcdata_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 263 "xml_lexer.mll"
  (
			Buffer.add_string tmp (lexeme lexbuf);
			pcdata lexbuf
		)
# 818 "xml_lexer.ml"

  | 1 ->
# 268 "xml_lexer.mll"
  (
			Buffer.add_string tmp (entity lexbuf);
			pcdata lexbuf
		)
# 826 "xml_lexer.ml"

  | 2 ->
# 273 "xml_lexer.mll"
  ( Buffer.contents tmp )
# 831 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_pcdata_rec lexbuf __ocaml_lex_state

and entity lexbuf =
   __ocaml_lex_entity_rec lexbuf 55
and __ocaml_lex_entity_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 277 "xml_lexer.mll"
  (
			let ident = lexeme lexbuf in
			try
				Hashtbl.find idents (String.lowercase ident)
			with
				Not_found -> "&" ^ ident
		)
# 849 "xml_lexer.ml"

  | 1 ->
# 286 "xml_lexer.mll"
        (
			let ident = lexeme lexbuf in
			try
				Hashtbl.find idents (String.lowercase ident)
			with
				Not_found -> "&" ^ ident
        )
# 860 "xml_lexer.ml"

  | 2 ->
# 294 "xml_lexer.mll"
  ( raise (Error EUnterminatedEntity) )
# 865 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_entity_rec lexbuf __ocaml_lex_state

and ident_name lexbuf =
   __ocaml_lex_ident_name_rec lexbuf 65
and __ocaml_lex_ident_name_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 298 "xml_lexer.mll"
  ( lexeme lexbuf )
# 877 "xml_lexer.ml"

  | 1 ->
# 300 "xml_lexer.mll"
  ( error lexbuf EIdentExpected )
# 882 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_ident_name_rec lexbuf __ocaml_lex_state

and close_tag lexbuf =
   __ocaml_lex_close_tag_rec lexbuf 68
and __ocaml_lex_close_tag_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 304 "xml_lexer.mll"
  ( () )
# 894 "xml_lexer.ml"

  | 1 ->
# 306 "xml_lexer.mll"
  ( error lexbuf ECloseExpected )
# 899 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_close_tag_rec lexbuf __ocaml_lex_state

and attributes lexbuf =
   __ocaml_lex_attributes_rec lexbuf 71
and __ocaml_lex_attributes_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 310 "xml_lexer.mll"
  ( [], false )
# 911 "xml_lexer.ml"

  | 1 ->
# 312 "xml_lexer.mll"
  ( [], true )
# 916 "xml_lexer.ml"

  | 2 ->
# 314 "xml_lexer.mll"
  (
			let key = attribute lexbuf in
			let data = attribute_data lexbuf in
			ignore_spaces lexbuf;
			let others, closed = attributes lexbuf in
			(key, data) :: others, closed
		)
# 927 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_attributes_rec lexbuf __ocaml_lex_state

and attribute lexbuf =
   __ocaml_lex_attribute_rec lexbuf 75
and __ocaml_lex_attribute_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 324 "xml_lexer.mll"
  ( lexeme lexbuf )
# 939 "xml_lexer.ml"

  | 1 ->
# 326 "xml_lexer.mll"
  ( error lexbuf EAttributeNameExpected )
# 944 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_attribute_rec lexbuf __ocaml_lex_state

and attribute_data lexbuf =
   __ocaml_lex_attribute_data_rec lexbuf 78
and __ocaml_lex_attribute_data_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 330 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			last_pos := lexeme_end lexbuf;
			dq_string lexbuf
		)
# 960 "xml_lexer.ml"

  | 1 ->
# 336 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			last_pos := lexeme_end lexbuf;
			q_string lexbuf
		)
# 969 "xml_lexer.ml"

  | 2 ->
# 342 "xml_lexer.mll"
  ( error lexbuf EAttributeValueExpected )
# 974 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_attribute_data_rec lexbuf __ocaml_lex_state

and dq_string lexbuf =
   __ocaml_lex_dq_string_rec lexbuf 86
and __ocaml_lex_dq_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 346 "xml_lexer.mll"
  ( Buffer.contents tmp )
# 986 "xml_lexer.ml"

  | 1 ->
# 348 "xml_lexer.mll"
  (
			Buffer.add_char tmp (lexeme_char lexbuf 1);
			dq_string lexbuf
		)
# 994 "xml_lexer.ml"

  | 2 ->
# 353 "xml_lexer.mll"
  ( raise (Error EUnterminatedString) )
# 999 "xml_lexer.ml"

  | 3 ->
# 355 "xml_lexer.mll"
  (
			Buffer.add_char tmp (lexeme_char lexbuf 0);
			dq_string lexbuf
		)
# 1007 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dq_string_rec lexbuf __ocaml_lex_state

and q_string lexbuf =
   __ocaml_lex_q_string_rec lexbuf 92
and __ocaml_lex_q_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 362 "xml_lexer.mll"
  ( Buffer.contents tmp )
# 1019 "xml_lexer.ml"

  | 1 ->
# 364 "xml_lexer.mll"
  (
			Buffer.add_char tmp (lexeme_char lexbuf 1);
			q_string lexbuf
		)
# 1027 "xml_lexer.ml"

  | 2 ->
# 369 "xml_lexer.mll"
  ( raise (Error EUnterminatedString) )
# 1032 "xml_lexer.ml"

  | 3 ->
# 371 "xml_lexer.mll"
  (
			Buffer.add_char tmp (lexeme_char lexbuf 0);
			q_string lexbuf
		)
# 1040 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_q_string_rec lexbuf __ocaml_lex_state

and dtd_data lexbuf =
   __ocaml_lex_dtd_data_rec lexbuf 98
and __ocaml_lex_dtd_data_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 378 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			(* skipping Public ID *)
			let _ = dtd_file lexbuf in
			let file = dtd_file lexbuf in
			dtd_end_decl lexbuf;
			DTDFile file
		)
# 1059 "xml_lexer.ml"

  | 1 ->
# 387 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			let file = dtd_file lexbuf in
			dtd_end_decl lexbuf;
			DTDFile file
		)
# 1069 "xml_lexer.ml"

  | 2 ->
# 394 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			let data = dtd_intern lexbuf in
			dtd_end_decl lexbuf;
			DTDData data
		)
# 1079 "xml_lexer.ml"

  | 3 ->
# 401 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDDecl )
# 1084 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_data_rec lexbuf __ocaml_lex_state

and dtd_file lexbuf =
   __ocaml_lex_dtd_file_rec lexbuf 113
and __ocaml_lex_dtd_file_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 405 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let s = dq_string lexbuf in
			ignore_spaces lexbuf;
			s
		)
# 1101 "xml_lexer.ml"

  | 1 ->
# 412 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let s = q_string lexbuf in
			ignore_spaces lexbuf;
			s
		)
# 1111 "xml_lexer.ml"

  | 2 ->
# 419 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDDecl )
# 1116 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_file_rec lexbuf __ocaml_lex_state

and dtd_intern lexbuf =
   __ocaml_lex_dtd_intern_rec lexbuf 117
and __ocaml_lex_dtd_intern_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 423 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			[]
		)
# 1131 "xml_lexer.ml"

  | 1 ->
# 428 "xml_lexer.mll"
  (
			let l = dtd_item lexbuf in
			l @ (dtd_intern lexbuf)
		)
# 1139 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_intern_rec lexbuf __ocaml_lex_state

and dtd lexbuf =
   __ocaml_lex_dtd_rec lexbuf 119
and __ocaml_lex_dtd_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 435 "xml_lexer.mll"
  ( [] )
# 1151 "xml_lexer.ml"

  | 1 ->
# 437 "xml_lexer.mll"
  (
			newline lexbuf;
			dtd lexbuf
		)
# 1159 "xml_lexer.ml"

  | 2 ->
# 442 "xml_lexer.mll"
  ( dtd lexbuf )
# 1164 "xml_lexer.ml"

  | 3 ->
# 444 "xml_lexer.mll"
  (
			let l = dtd_item lexbuf in
			l @ (dtd lexbuf)
		)
# 1172 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_rec lexbuf __ocaml_lex_state

and dtd_end_decl lexbuf =
   __ocaml_lex_dtd_end_decl_rec lexbuf 123
and __ocaml_lex_dtd_end_decl_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 451 "xml_lexer.mll"
  ( ignore_spaces lexbuf )
# 1184 "xml_lexer.ml"

  | 1 ->
# 453 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDDecl )
# 1189 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_end_decl_rec lexbuf __ocaml_lex_state

and dtd_item lexbuf =
   __ocaml_lex_dtd_item_rec lexbuf 126
and __ocaml_lex_dtd_item_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 457 "xml_lexer.mll"
  (
			comment lexbuf;
			[];
		)
# 1204 "xml_lexer.ml"

  | 1 ->
# 462 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			let t = dtd_item_type lexbuf in
			let name = (try ident_name lexbuf with Error EIdentExpected -> raise (DTDError EInvalidDTDDecl)) in
			ignore_spaces lexbuf;
			match t with
			| TElement -> [ DTDElement (name , (dtd_element_type lexbuf)) ]
			| TAttribute -> List.map (fun (attrname,atype,adef) -> DTDAttribute (name, attrname, atype, adef)) (dtd_attributes lexbuf)
		)
# 1217 "xml_lexer.ml"

  | 2 ->
# 472 "xml_lexer.mll"
  (  dtd_error lexbuf EDTDItemExpected )
# 1222 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_item_rec lexbuf __ocaml_lex_state

and dtd_attributes lexbuf =
   __ocaml_lex_dtd_attributes_rec lexbuf 132
and __ocaml_lex_dtd_attributes_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 476 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			[]
		)
# 1237 "xml_lexer.ml"

  | 1 ->
# 481 "xml_lexer.mll"
  (
			let attrname = (try ident_name lexbuf with Error EIdentExpected -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			let atype = dtd_attr_type lexbuf in
			let adef = dtd_attr_default lexbuf in
			let a = (attrname, atype, adef) in
			a :: (dtd_attributes lexbuf)
		)
# 1249 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attributes_rec lexbuf __ocaml_lex_state

and dtd_item_type lexbuf =
   __ocaml_lex_dtd_item_type_rec lexbuf 134
and __ocaml_lex_dtd_item_type_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 492 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			TElement
		)
# 1264 "xml_lexer.ml"

  | 1 ->
# 497 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			TAttribute
		)
# 1272 "xml_lexer.ml"

  | 2 ->
# 502 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDTag )
# 1277 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_item_type_rec lexbuf __ocaml_lex_state

and dtd_element_type lexbuf =
   __ocaml_lex_dtd_element_type_rec lexbuf 150
and __ocaml_lex_dtd_element_type_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 506 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			dtd_end_element lexbuf;
			DTDAny
		)
# 1293 "xml_lexer.ml"

  | 1 ->
# 512 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			dtd_end_element lexbuf;
			DTDEmpty
		)
# 1302 "xml_lexer.ml"

  | 2 ->
# 518 "xml_lexer.mll"
  (
			try
				let item = Xml_parser.dtd_element dtd_element_token lexbuf in
				ignore_spaces lexbuf;
				DTDChild item
			with
				Parsing.Parse_error -> dtd_error lexbuf EInvalidDTDElement
		)
# 1314 "xml_lexer.ml"

  | 3 ->
# 527 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDElement )
# 1319 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_element_type_rec lexbuf __ocaml_lex_state

and dtd_end_element lexbuf =
   __ocaml_lex_dtd_end_element_rec lexbuf 161
and __ocaml_lex_dtd_end_element_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 531 "xml_lexer.mll"
  ( ignore_spaces lexbuf )
# 1331 "xml_lexer.ml"

  | 1 ->
# 533 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDElement )
# 1336 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_end_element_rec lexbuf __ocaml_lex_state

and dtd_end_attribute lexbuf =
   __ocaml_lex_dtd_end_attribute_rec lexbuf 164
and __ocaml_lex_dtd_end_attribute_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 537 "xml_lexer.mll"
  ( ignore_spaces lexbuf )
# 1348 "xml_lexer.ml"

  | 1 ->
# 539 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1353 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_end_attribute_rec lexbuf __ocaml_lex_state

and dtd_element_token lexbuf =
   __ocaml_lex_dtd_element_token_rec lexbuf 167
and __ocaml_lex_dtd_element_token_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 543 "xml_lexer.mll"
  (
			newline lexbuf;
			dtd_element_token lexbuf
		)
# 1368 "xml_lexer.ml"

  | 1 ->
# 548 "xml_lexer.mll"
  ( dtd_element_token lexbuf )
# 1373 "xml_lexer.ml"

  | 2 ->
# 550 "xml_lexer.mll"
  ( OPEN )
# 1378 "xml_lexer.ml"

  | 3 ->
# 552 "xml_lexer.mll"
  ( CLOSE )
# 1383 "xml_lexer.ml"

  | 4 ->
# 554 "xml_lexer.mll"
  ( NEXT )
# 1388 "xml_lexer.ml"

  | 5 ->
# 556 "xml_lexer.mll"
  ( END )
# 1393 "xml_lexer.ml"

  | 6 ->
# 558 "xml_lexer.mll"
  ( OR )
# 1398 "xml_lexer.ml"

  | 7 ->
# 560 "xml_lexer.mll"
  ( PCDATA )
# 1403 "xml_lexer.ml"

  | 8 ->
# 562 "xml_lexer.mll"
  ( STAR )
# 1408 "xml_lexer.ml"

  | 9 ->
# 564 "xml_lexer.mll"
  ( PLUS )
# 1413 "xml_lexer.ml"

  | 10 ->
# 566 "xml_lexer.mll"
  ( QUESTION )
# 1418 "xml_lexer.ml"

  | 11 ->
# 568 "xml_lexer.mll"
  ( IDENT (lexeme lexbuf) )
# 1423 "xml_lexer.ml"

  | 12 ->
# 570 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDElement )
# 1428 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_element_token_rec lexbuf __ocaml_lex_state

and dtd_attr_type lexbuf =
   __ocaml_lex_dtd_attr_type_rec lexbuf 187
and __ocaml_lex_dtd_attr_type_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 574 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDCData
		)
# 1443 "xml_lexer.ml"

  | 1 ->
# 579 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDNMToken
		)
# 1451 "xml_lexer.ml"

  | 2 ->
# 584 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
		 	DTDID
		)
# 1459 "xml_lexer.ml"

  | 3 ->
# 589 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDIDRef
		)
# 1467 "xml_lexer.ml"

  | 4 ->
# 594 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDEnum (dtd_attr_enum lexbuf)
		)
# 1475 "xml_lexer.ml"

  | 5 ->
# 599 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1480 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_type_rec lexbuf __ocaml_lex_state

and dtd_attr_enum lexbuf =
   __ocaml_lex_dtd_attr_enum_rec lexbuf 207
and __ocaml_lex_dtd_attr_enum_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 603 "xml_lexer.mll"
  (
			let v = lexeme lexbuf in
			ignore_spaces lexbuf;
			v :: (dtd_attr_enum_next lexbuf)
		)
# 1496 "xml_lexer.ml"

  | 1 ->
# 609 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1501 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_enum_rec lexbuf __ocaml_lex_state

and dtd_attr_enum_next lexbuf =
   __ocaml_lex_dtd_attr_enum_next_rec lexbuf 210
and __ocaml_lex_dtd_attr_enum_next_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 613 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			[]
		)
# 1516 "xml_lexer.ml"

  | 1 ->
# 618 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			dtd_attr_enum lexbuf
		)
# 1524 "xml_lexer.ml"

  | 2 ->
# 623 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1529 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_enum_next_rec lexbuf __ocaml_lex_state

and dtd_attr_default lexbuf =
   __ocaml_lex_dtd_attr_default_rec lexbuf 214
and __ocaml_lex_dtd_attr_default_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 627 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let v = (try dq_string lexbuf with Error EUnterminatedString -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			DTDDefault v
		)
# 1546 "xml_lexer.ml"

  | 1 ->
# 634 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let v = (try q_string lexbuf with Error EUnterminatedString -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			DTDDefault v
		)
# 1556 "xml_lexer.ml"

  | 2 ->
# 641 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDRequired
		)
# 1564 "xml_lexer.ml"

  | 3 ->
# 646 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDImplied
		)
# 1572 "xml_lexer.ml"

  | 4 ->
# 651 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDFixed (dtd_attr_string lexbuf)
		)
# 1580 "xml_lexer.ml"

  | 5 ->
# 656 "xml_lexer.mll"
  (
			ignore_spaces lexbuf;
			DTDDefault (dtd_attr_string lexbuf)
		)
# 1588 "xml_lexer.ml"

  | 6 ->
# 661 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1593 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_default_rec lexbuf __ocaml_lex_state

and dtd_attr_string lexbuf =
   __ocaml_lex_dtd_attr_string_rec lexbuf 246
and __ocaml_lex_dtd_attr_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 665 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let v = (try dq_string lexbuf with Error EUnterminatedString -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			v
		)
# 1610 "xml_lexer.ml"

  | 1 ->
# 672 "xml_lexer.mll"
  (
			Buffer.reset tmp;
			let v = (try q_string lexbuf with Error EUnterminatedString -> raise (DTDError EInvalidDTDAttribute)) in
			ignore_spaces lexbuf;
			v
		)
# 1620 "xml_lexer.ml"

  | 2 ->
# 679 "xml_lexer.mll"
  ( dtd_error lexbuf EInvalidDTDAttribute )
# 1625 "xml_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_dtd_attr_string_rec lexbuf __ocaml_lex_state

;;

